@@ -22,14 +22,13 @@ fn perf_test_multi(q_num: usize, t_num: usize) {
 
 fn performance(c: &mut Criterion) {
     for qu_num in [18, 19, 20] {
-        c.bench_function(format!("evaluate_qu{}_single", qu_num).as_str(), |b| {
+        c.bench_function(format!("evaluate_qu{qu_num}_single").as_str(), |b| {
             b.iter(|| perf_test_single(black_box(qu_num)))
         });
         for th_num in 1..=rayon::current_num_threads() {
-            c.bench_function(
-                format!("evaluate_qu{}_th{}", qu_num, th_num).as_str(),
-                |b| b.iter(|| perf_test_multi(black_box(qu_num), black_box(th_num))),
-            );
+            c.bench_function(format!("evaluate_qu{qu_num}_th{th_num}").as_str(), |b| {
+                b.iter(|| perf_test_multi(black_box(qu_num), black_box(th_num)))
+            });
         }
     }
 }
